@@ -62,7 +62,12 @@ from struct import pack
 from binascii import crc32
 
 from gitdb.const import NULL_BYTE
-from gitdb.utils.compat import izip, buffer, xrange
+from gitdb.utils.compat import (
+    izip, 
+    buffer, 
+    xrange,
+    to_bytes
+)
 
 import tempfile
 import array
@@ -864,7 +869,7 @@ class PackEntity(LazyMixin):
             stream = streams[-1]
             while stream.type_id in delta_types:
                 if stream.type_id == REF_DELTA:
-                    sindex = self._index.sha_to_index(stream.delta_info)
+                    sindex = self._index.sha_to_index(to_bytes(stream.delta_info))
                     if sindex is None:
                         break
                     stream = self._pack.stream(self._index.offset(sindex))
