@@ -13,22 +13,17 @@ k_env_git_repo = "GITDB_TEST_GIT_REPO_BASE"
 #} END invariants
 
 
-
-#{ Base Classes 
+#{ Base Classes
 
 class TestBigRepoR(TestBase):
+
     """TestCase providing access to readonly 'big' repositories using the following 
     member variables:
-    
+
     * gitrepopath
-    
+
      * read-only base path of the git source repository, i.e. .../git/.git"""
-     
-    #{ Invariants
-    head_sha_2k = '235d521da60e4699e5bd59ac658b5b48bd76ddca'
-    head_sha_50 = '32347c375250fd470973a5d76185cac718955fd5'
-    #} END invariants 
-    
+
     def setUp(self):
         try:
             super(TestBigRepoR, self).setUp()
@@ -37,11 +32,12 @@ class TestBigRepoR(TestBase):
 
         self.gitrepopath = os.environ.get(k_env_git_repo)
         if not self.gitrepopath:
-            logging.info("You can set the %s environment variable to a .git repository of your choice - defaulting to the gitdb repository")
+            logging.info(
+                "You can set the %s environment variable to a .git repository of your choice - defaulting to the gitdb repository", k_env_git_repo)
             ospd = os.path.dirname
             self.gitrepopath = os.path.join(ospd(ospd(ospd(ospd(__file__)))), '.git')
         # end assure gitrepo is set
         assert self.gitrepopath.endswith('.git')
 
-        
+
 #} END base classes
